==> huaweicloudsdkworkspace-3.1.87-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/agencies_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgenciesInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'permissions': 'list[AgenciesPermissionInfo]'
    }

    attribute_map = {
        'name': 'name',
        'permissions': 'permissions'
    }

    def __init__(self, name=None, permissions=None):
        """AgenciesInfo

        The model defined in huaweicloud sdk

        :param name: 名称
        :type name: str
        :param permissions: 委托权限信息
        :type permissions: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        
        

        self._name = None
        self._permissions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if permissions is not None:
            self.permissions = permissions

    @property
    def name(self):
        """Gets the name of this AgenciesInfo.

        名称

        :return: The name of this AgenciesInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AgenciesInfo.

        名称

        :param name: The name of this AgenciesInfo.
        :type name: str
        """
        self._name = name

    @property
    def permissions(self):
        """Gets the permissions of this AgenciesInfo.

        委托权限信息

        :return: The permissions of this AgenciesInfo.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this AgenciesInfo.

        委托权限信息

        :param permissions: The permissions of this AgenciesInfo.
        :type permissions: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgenciesInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/agencies_info.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AgenciesInfo:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'permissions': 'list[AgenciesPermissionInfo]'
    }

    attribute_map = {
        'name': 'name',
        'permissions': 'permissions'
    }

    def __init__(self, name=None, permissions=None):
        r"""AgenciesInfo

        The model defined in huaweicloud sdk

        :param name: 名称
        :type name: str
        :param permissions: 委托权限信息
        :type permissions: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        
        

        self._name = None
        self._permissions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if permissions is not None:
            self.permissions = permissions

    @property
    def name(self):
        r"""Gets the name of this AgenciesInfo.

        名称

        :return: The name of this AgenciesInfo.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this AgenciesInfo.

        名称

        :param name: The name of this AgenciesInfo.
        :type name: str
        """
        self._name = name

    @property
    def permissions(self):
        r"""Gets the permissions of this AgenciesInfo.

        委托权限信息

        :return: The permissions of this AgenciesInfo.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        r"""Sets the permissions of this AgenciesInfo.

        委托权限信息

        :param permissions: The permissions of this AgenciesInfo.
        :type permissions: list[:class:`huaweicloudsdkworkspace.v2.AgenciesPermissionInfo`]
        """
        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgenciesInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
